<?php
/**
 * Set up the WordPress core custom header feature.
 *
 * @uses newsera_news_header_style()
 */
function newsera_news_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'newsera_news_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '#614241',
		'width'                  => 1000,
		'height'                 => 250,
		'flex-height'            => true,
		'wp-head-callback'       => 'newsera_news_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'newsera_news_custom_header_setup' );

if ( ! function_exists( 'newsera_news_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog.
 *
 * @see newsera_news_custom_header_setup().
 */
function newsera_news_header_style() {
	$header_text_color = get_header_textcolor();

	/*
	 * If no custom options for text are set, let's bail.
	 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: HEADER_TEXTCOLOR.
	 */
	if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
		return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) : ?>
		.logo h1 {
		color: #f36100;
		position:absolute;
		clip: rect(1px 1px 1px 1px);
		}
		.logo p {
		color: #f36100;
		position:absolute;
		clip: rect(1px 1px 1px 1px);
		}
		.col-md-12.date{
		color:#fff;	
		}
	<?php
		// If the user has set a custom color for the text use that.
		else :	?>
		a.brand h1, a.brand p, .col-md-12.date{
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php } endif; ?>